# Terminology

This document is a continual work in progress. Please feel free to contribute.

| Term | Description |
| --- | --- |
| **server** | A MCP server. e.g. MCP-wolfram-alpha, MCP-searxng, MCP-timeserver |
| **bridge** | The MCP-Bridge application |
| **client** | A generic MCP client. e.g. claude desktop. This includes the bridge |
| **upstream** | The MCP-SDK |
| **inference engine** | LLM runtime such as ollama, vllm, openai api |
